#
# spec file for package perl-Apache-Session
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Apache-Session
Name:           perl-Apache-Session
Version:        1.940.0
Release:        1.1
# 1.94 -> normalize -> 1.940.0
%define cpan_version 1.94
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Persistence framework for session data
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/C/CH/CHORNY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Test::Deep) >= 0.82
BuildRequires:  perl(Test::Exception) >= 0.15
Provides:       perl(Apache::Session) = %{version}
Provides:       perl(Apache::Session::DB_File) = 1.10.0
Provides:       perl(Apache::Session::File) = 1.540.0
Provides:       perl(Apache::Session::Flex) = 1.10.0
Provides:       perl(Apache::Session::Generate::MD5) = 2.120.0
Provides:       perl(Apache::Session::Generate::ModUniqueId) = 0.20.0
Provides:       perl(Apache::Session::Generate::ModUsertrack) = 0.20.0
Provides:       perl(Apache::Session::Informix) = 1.10.0
Provides:       perl(Apache::Session::Lock::File) = 1.40.0
Provides:       perl(Apache::Session::Lock::MySQL) = 1.10.0
Provides:       perl(Apache::Session::Lock::Null) = 1.10.0
Provides:       perl(Apache::Session::Lock::Semaphore) = 1.40.0
Provides:       perl(Apache::Session::Lock::Sybase) = 1.0.0
Provides:       perl(Apache::Session::MySQL) = 1.10.0
Provides:       perl(Apache::Session::MySQL::NoLock) = 0.10.0
Provides:       perl(Apache::Session::Oracle) = 1.10.0
Provides:       perl(Apache::Session::Postgres) = 1.10.0
Provides:       perl(Apache::Session::Serialize::Base64) = 1.10.0
Provides:       perl(Apache::Session::Serialize::Storable) = 1.10.0
Provides:       perl(Apache::Session::Serialize::Sybase) = 1.0.0
Provides:       perl(Apache::Session::Serialize::UUEncode) = 1.10.0
Provides:       perl(Apache::Session::Store::DBI) = 1.20.0
Provides:       perl(Apache::Session::Store::DB_File) = 1.10.0
Provides:       perl(Apache::Session::Store::File) = 1.40.0
Provides:       perl(Apache::Session::Store::Informix) = 1.20.0
Provides:       perl(Apache::Session::Store::MySQL) = 1.40.0
Provides:       perl(Apache::Session::Store::Oracle) = 1.100.0
Provides:       perl(Apache::Session::Store::Postgres) = 1.30.0
Provides:       perl(Apache::Session::Store::Sybase) = 1.10.0
Provides:       perl(Apache::Session::Sybase) = 1.0.0
%undefine       __perllib_provides
%{perl_requires}

%description
Apache::Session is a persistence framework which is particularly useful for
tracking session data between httpd requests. Apache::Session is designed
to work with Apache and mod_perl, but it should work under CGI and other
web servers, and it also works outside of a web server altogether.

Apache::Session consists of five components: the interface, the object
store, the lock manager, the ID generator, and the serializer. The
interface is defined in Session.pm, which is meant to be easily subclassed.
The object store can be the filesystem, a Berkeley DB, a MySQL DB, an
Oracle DB, a Postgres DB, Sybase, or Informix. Locking is done by lock
files, semaphores, or the locking capabilities of the various databases.
Serialization is done via Storable, and optionally ASCII-fied via MIME or
pack(). ID numbers are generated via MD5. The reader is encouraged to
extend these capabilities to meet his own requirements.

A derived class of Apache::Session is used to tie together the three
following components. The derived class inherits the interface from
Apache::Session, and specifies which store and locker classes to use.
Apache::Session::MySQL, for instance, uses the MySQL storage class and also
the MySQL locking class. You can easily plug in your own object store or
locker class.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGES Contributing.txt README TODO

%changelog
* Tue Jun  3 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Sat Sep 19 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.94
  see /usr/share/doc/packages/perl-Apache-Session/CHANGES
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.93
  see /usr/share/doc/packages/perl-Apache-Session/CHANGES
  1.93  2014-04-12
  - even more test fixes
  1.92  2014-03-08
  - more test fixes
* Mon Feb 24 2014 coolo@suse.com
- updated to 1.91
  - Add a test for RT#50896
  - 99mysql.t will work more correctly in some corner cases
* Mon Jun  3 2013 coolo@suse.com
- updated to 1.90
  - Allow specifying table for Oracle
  - Use Test::Database for tests
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Sep 23 2010 anicka@suse.cz
- update to 1.89
  * require Digest::MD5
  * all semaphore tests were removed
  * Apache::Session::Store::File::materialize should not append
    to $session->{serialized}
  * Apache::Session::Store::File will flush after writing to file
  * Apache::Session::Generate::MD5::validate will untaint data
  * MIN_PERL_VERSION in Makefile.PL
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Sep 10 2008 anicka@suse.cz
- update to 1.87
  * disabled 99semaphore.t. Help needed.
  * correct number of tests in 99semaphore.t
  * use Carp::confess in Apache::Session::Lock::Semaphore
  * more info in die message in Apache::Session::Generate::MD5
  * semaphore tests check for semctl availability
  * Makefile.PL prints message if perl version < 5.006
* Tue Feb  5 2008 anicka@suse.cz
- update to 1.86
  * Default number of semaphores for *BSD is 8
    in Apache::Session::Lock::Semaphore
* Fri Jan  4 2008 anicka@suse.cz
- update to 1.85
  * mention Catalyst::Plugin::Session, Session
  * Added Apache::Session::Lock::Semaphore::remove to remove
    semaphore
  * pod.t included in MANIFEST
  * test fixes
* Mon Oct  8 2007 anicka@suse.cz
- update to 1.84
  * Added constant.pm to the list of prerequisites
  * Jeffrey W. Baker, Casey West, Alexandr Ciornii, Oliver Maul
    agreed to change license of all files to Perl license
    Alexandr Ciornii agrees to relicense to Artistic 2.0 in future
    if needed.
  * 99flex.t will be skipped on *bsd or Solaris
* Mon Jun 11 2007 anicka@suse.cz
- update to 1.83 (upstream just raised the version number)
* Thu Feb 22 2007 anicka@suse.cz
- update to 1.82
  * Slightly faster test skip
  * 99semaphore.t and 99flex.t check for cygserver on Cygwin
  * 99flex.t skips less tests in some cases
  * 99flex.t checks for Digest::MD5, MIME::Base64
  * Warning in Apache::Session::Lock::Semaphore about cygserver
  * Makefile.PL requires File::Temp
  * changed order of use/chdir in tests
* Tue Jul 11 2006 anicka@suse.cz
- update to 1.81
- minor release
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 anicka@suse.cz
- update to 1.80
- fix neededforbuild
- disable all tests as we do not have Test::Deep yet
* Fri Oct 21 2005 dmueller@suse.de
- skip test that sometimes fails as nonroot
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Aug 13 2004 mjancar@suse.cz
- update to 1.6
* Tue Jun 15 2004 ro@suse.de
- updated requires
* Wed May  5 2004 mjancar@suse.cz
- update neededforbuild
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Tue Jun 17 2003 mjancar@suse.cz
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Sat Dec 28 2002 prehak@suse.cz
- reenabled test for all archs
* Wed Sep 11 2002 prehak@suse.cz
  disabled make test for x86_64
* Fri Aug 23 2002 prehak@suse.cz
- disabled make test on ppc64
* Mon Jul 29 2002 mls@suse.de
- Fixed neededforbuild for perl-5.8.0
* Mon Jul 22 2002 prehak@suse.cz
- doesn't require any specific apache version,
  simply require apache [#16775]
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Wed Jun 26 2002 prehak@suse.cz
- correct permissions of eg directory
* Mon Dec 17 2001 cihlar@suse.cz
- update to 1.54:
  * Added mod_uniqueid and mod_usertrack generators
  * Fixed validate function in Flex
  * Move to Digest::MD5 instead of MD5
- removed obsolete patch
- added %%clean
* Mon Nov  5 2001 poeml@suse.de
- use apache-devel-packages macro in #neededforbuild
  (expat.rpm is needed by apxs)
* Tue Aug 14 2001 ro@suse.de
- use Digest::MD5 instead of deprecated MD5
* Fri Feb 23 2001 ro@suse.de
- changed neededforbuild <apache> to <apache apache-devel>
* Fri Nov 17 2000 rolf@suse.de
- extracted from perlmod package
